@@ -1,5 +1,5 @@
 # source: 20210922_AntibodyTiters_1.txt
 idABT <- function(objName = "inData"){
-	if(class(get(objName)) != "ABT") stop("The class must be ABT\n")
+	if(inherits(get(objName), "ABT") != TRUE) stop("The class must be ABT\n")
 	return(get(objName)$DATA$ID)
 }
